Complex

Struct Complex 

#[repr(C)]
pub struct Complex<FT> { pub re: FT, pub im: FT, }
A complex number in rectangular form.

Fields

re: FTim: FT

Implementations

Source

impl Complex<f32>

pub const NEG_ONE: Self

pub const NEG_I: Self

pub fn as_vec2(self) -> Vec2

Casts to a glam::Vec2.

Source

impl Complex<f64>

pub const NEG_ONE: Self

pub const NEG_I: Self

pub fn as_vec2(self) -> Vec2

Casts to a glam::Vec2.

pub fn as_dvec2(self) -> DVec2

Casts to a glam::DVec2.

Source

impl<FT> Complex<FT>

pub const fn new(re: FT, im: FT) -> Self

Creates a complex number.

Source

impl<FT: Number> Complex<FT>

pub const ZERO: Self

pub const ONE: Self

pub const I: Self

pub fn conjugate(self) -> Self

Computes the conjugate.

pub fn abs(self) -> FT

Computes the absolute value.

pub fn square(self) -> Self

pub fn abs_sq(self) -> FT

Computes the squared absolute value.

This is faster than abs() as it avoids a square root operation.

pub fn arg(self) -> FT

Computes the argument in the range (-π, +π].

pub fn recip(self) -> Self

Computes the reciprocal.

pub fn to_polar(self) -> Polar<FT>

Convert to polar form.

pub fn exp(self) -> Polar<FT>

Computes e^self where e is the base of the natural logarithm.

pub fn exp2(self) -> Polar<FT>

Computes 2^self.

pub fn ln(self) -> Self

Computes the principle natural logarithm.

pub fn log2(self) -> Self

Computes the principle logarithm in base 2.

pub fn log10(self) -> Self

Computes the principle logarithm in base 10.

pub fn powi(self, n: i32) -> Polar<FT>

Raises self to an integer power.

pub fn powf(self, x: FT) -> Polar<FT>

Raises self to a floating point power.

pub fn sqrt(self) -> Self

Computes the principle square root.

pub fn distance(self, other: Self) -> FT

Computes the euclidian distance between two points.

pub fn distance_squared(self, other: Self) -> FT

Computes the squared euclidian distance between two points.

pub fn lerp(self, other: Self, t: FT) -> Self

Computes the linear interpolation between two points based on the value t.