#[repr(C)]pub struct ComplexPolar<FT> {
pub abs: FT,
pub arg: FT,
}Expand description
A complex number in polar form.
Fields
abs: FTarg: FTImplementations
Sourceimpl ComplexPolar<f32>
impl ComplexPolar<f32>
Sourceimpl ComplexPolar<f64>
impl ComplexPolar<f64>
Sourceimpl<FT> ComplexPolar<FT>
impl<FT> ComplexPolar<FT>
Sourceimpl<FT: Number> ComplexPolar<FT>
impl<FT: Number> ComplexPolar<FT>
pub const ZERO: Self
pub const ONE: Self
Sourcepub fn to_rectangular(self) -> Rectangular<FT>
pub fn to_rectangular(self) -> Rectangular<FT>
Convert to rectangular form.
Sourcepub fn expm1(self) -> Rectangular<FT>
pub fn expm1(self) -> Rectangular<FT>
Computes e^self - 1.
More numerically stable than self.exp().to_rectangular() - 1 when self ≈ 0.
Sourcepub fn ln(self) -> Rectangular<FT>
pub fn ln(self) -> Rectangular<FT>
Computes the principal natural logarithm.
Sourcepub fn ln_1p(self) -> Rectangular<FT>
pub fn ln_1p(self) -> Rectangular<FT>
Computes the principal natural logarithm of 1 + self.
More numerically stable than (self + 1).ln() when self ≈ 0.
Sourcepub fn log2(self) -> Rectangular<FT>
pub fn log2(self) -> Rectangular<FT>
Computes the principal logarithm in base 2.
Sourcepub fn log10(self) -> Rectangular<FT>
pub fn log10(self) -> Rectangular<FT>
Computes the principal logarithm in base 10.
Sourcepub fn ln_branch(self, k: i32) -> Rectangular<FT>
pub fn ln_branch(self, k: i32) -> Rectangular<FT>
Computes the k-th branch of the natural logarithm.
The principal value is k = 0. Each increment of k adds 2πi.
Sourcepub fn ln_1p_branch(self, k: i32) -> Rectangular<FT>
pub fn ln_1p_branch(self, k: i32) -> Rectangular<FT>
Computes the k-th branch of the natural logarithm of 1 + self.
The principal value is k = 0. Each increment of k adds 2πi.
Sourcepub fn log2_branch(self, k: i32) -> Rectangular<FT>
pub fn log2_branch(self, k: i32) -> Rectangular<FT>
Computes the k-th branch of the base-2 logarithm.
Sourcepub fn log10_branch(self, k: i32) -> Rectangular<FT>
pub fn log10_branch(self, k: i32) -> Rectangular<FT>
Computes the k-th branch of the base-10 logarithm.
Sourcepub fn sqrt_branch(self, k: i32) -> Self
pub fn sqrt_branch(self, k: i32) -> Self
Computes the k-th square root.
The principal value is k = 0. Only k = 0 and k = 1 give distinct values.
Sourcepub fn nth_root(self, n: i32, k: i32) -> Self
pub fn nth_root(self, n: i32, k: i32) -> Self
Computes the k-th value of the n-th root.
The n distinct values correspond to k = 0..n-1.
Sourcepub fn pow_rational(self, p: i32, q: i32, k: i32) -> Self
pub fn pow_rational(self, p: i32, q: i32, k: i32) -> Self
Raises self to the rational power p/q, selecting the k-th branch.
There are q distinct values corresponding to k = 0..q-1, provided p/q is in lowest
terms. If p/q is not reduced, first reduce it to find the true number of distinct values.