#[repr(C)]pub struct Complex<FT> {
pub re: FT,
pub im: FT,
}Expand description
A complex number in rectangular form.
Fields
re: FTim: FTImplementations
Sourceimpl<FT: Number> Complex<FT>
impl<FT: Number> Complex<FT>
pub const ZERO: Self
pub const ONE: Self
pub const I: Self
pub fn square(self) -> Self
Sourcepub fn abs_sq(self) -> FT
pub fn abs_sq(self) -> FT
Computes the squared absolute value.
This is faster than abs() as it avoids a square root operation.
Sourcepub fn expm1(self) -> Self
pub fn expm1(self) -> Self
Computes e^self - 1.
More numerically stable than self.exp().to_rectangular() - 1 when self ≈ 0.
Sourcepub fn ln_1p(self) -> Self
pub fn ln_1p(self) -> Self
Computes the principal natural logarithm of 1 + self.
More numerically stable than (self + 1).ln() when self ≈ 0.
Sourcepub fn ln_branch(self, k: i32) -> Self
pub fn ln_branch(self, k: i32) -> Self
Computes the k-th branch of the natural logarithm.
The principal value is k = 0. Each increment of k adds 2πi.
Sourcepub fn ln_1p_branch(self, k: i32) -> Self
pub fn ln_1p_branch(self, k: i32) -> Self
Computes the k-th branch of the natural logarithm of 1 + self.
The principal value is k = 0. Each increment of k adds 2πi.
Sourcepub fn log2_branch(self, k: i32) -> Self
pub fn log2_branch(self, k: i32) -> Self
Computes the k-th branch of the base-2 logarithm.
Sourcepub fn log10_branch(self, k: i32) -> Self
pub fn log10_branch(self, k: i32) -> Self
Computes the k-th branch of the base-10 logarithm.
Sourcepub fn sqrt_branch(self, k: i32) -> Polar<FT>
pub fn sqrt_branch(self, k: i32) -> Polar<FT>
Computes the k-th square root.
The principal value is k = 0. Only k = 0 and k = 1 give distinct values.
Sourcepub fn nth_root(self, n: i32, k: i32) -> Polar<FT>
pub fn nth_root(self, n: i32, k: i32) -> Polar<FT>
Computes the k-th value of the n-th root.
The n distinct values correspond to k = 0..n-1.
Sourcepub fn pow_rational(self, p: i32, q: i32, k: i32) -> Polar<FT>
pub fn pow_rational(self, p: i32, q: i32, k: i32) -> Polar<FT>
Raises self to the rational power p/q, selecting the k-th branch.
There are q distinct values corresponding to k = 0..q-1, provided p/q is in lowest
terms. If p/q is not reduced, first reduce it to find the true number of distinct values.
Sourcepub fn distance_squared(self, other: Self) -> FT
pub fn distance_squared(self, other: Self) -> FT
Computes the squared euclidian distance between two points.
Sourceimpl<FT: AsPrimitive<f32>> Complex<FT>
impl<FT: AsPrimitive<f32>> Complex<FT>