#[repr(C)]pub struct Complex<FT> {
pub re: FT,
pub im: FT,
}Expand description
A complex number in rectangular form.
Fields
re: FTim: FTImplementations
Sourceimpl Complex<f32>
impl Complex<f32>
pub const ZERO: Self
pub const ONE: Self
pub const NEG_ONE: Self
pub const I: Self
pub const NEG_I: Self
Sourcepub fn abs_sq(self) -> f32
pub fn abs_sq(self) -> f32
Computes the squared absolute value.
This is faster than abs() as it avoids a square root operation.
Sourcepub fn to_polar(self) -> ComplexPolar<f32>
pub fn to_polar(self) -> ComplexPolar<f32>
Convert to polar form.
Sourcepub fn exp(self) -> ComplexPolar<f32>
pub fn exp(self) -> ComplexPolar<f32>
Computes e^self where e is the base of the natural logarithm.
Sourcepub fn powi(self, n: i32) -> ComplexPolar<f32>
pub fn powi(self, n: i32) -> ComplexPolar<f32>
Raises self to an integer power.
Sourcepub fn powf(self, x: f32) -> ComplexPolar<f32>
pub fn powf(self, x: f32) -> ComplexPolar<f32>
Raises self to a floating point power.
Sourcepub fn distance_squared(self, other: Self) -> f32
pub fn distance_squared(self, other: Self) -> f32
Computes the squared euclidian distance between two points.
Sourceimpl Complex<f64>
impl Complex<f64>
pub const ZERO: Self
pub const ONE: Self
pub const NEG_ONE: Self
pub const I: Self
pub const NEG_I: Self
Sourcepub fn abs_sq(self) -> f64
pub fn abs_sq(self) -> f64
Computes the squared absolute value.
This is faster than abs() as it avoids a square root operation.
Sourcepub fn to_polar(self) -> ComplexPolar<f64>
pub fn to_polar(self) -> ComplexPolar<f64>
Convert to polar form.
Sourcepub fn exp(self) -> ComplexPolar<f64>
pub fn exp(self) -> ComplexPolar<f64>
Computes e^self where e is the base of the natural logarithm.
Sourcepub fn powi(self, n: i32) -> ComplexPolar<f64>
pub fn powi(self, n: i32) -> ComplexPolar<f64>
Raises self to an integer power.
Sourcepub fn powf(self, x: f64) -> ComplexPolar<f64>
pub fn powf(self, x: f64) -> ComplexPolar<f64>
Raises self to a floating point power.
Sourcepub fn distance_squared(self, other: Self) -> f64
pub fn distance_squared(self, other: Self) -> f64
Computes the squared euclidian distance between two points.